@@ -123,7 +123,8 @@ class GitHubSource(NvdSource):
                 config.gha_url, type
             )
         )
-        r = httpx.post(url=config.gha_url, json=get_query(type=type), headers=headers)
+        client = httpx.Client(http2=True, follow_redirects=True, timeout=180)
+        r = client.post(url=config.gha_url, json=get_query(type=type), headers=headers)
         json_data = r.json()
         return self.convert(json_data)
 
