@@ -55,9 +55,10 @@ class OSVSource(NvdSource):
 
     def fetch(self, url):
         ret_data = []
+        client = httpx.Client(http2=True, follow_redirects=True, timeout=180)
         with CustomNamedTemporaryFile() as tf:
             try:
-                with httpx.stream("GET", url, follow_redirects=True) as r:
+                with client.stream("GET", url) as r:
                     for chunk in r.iter_bytes(chunk_size=download_chunk_size):
                         tf.write(chunk)
                     tf.flush()
@@ -71,7 +72,7 @@ class OSVSource(NvdSource):
                             try:
                                 json_data = json_lib.loads(cve_data)
                                 ret_data += self.convert(json_data)
-                            except Exception as e:
+                            except Exception:
                                 pass
         return ret_data
 
@@ -289,6 +290,6 @@ class OSVSource(NvdSource):
                                 vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                                 vuln.description = description
                                 ret_data.append(vuln)
-                            except Exception as e:
+                            except Exception:
                                 pass
         return ret_data
